// Autogenerated by ARMTargetDefEmitter.cpp

#ifndef ARM_PROCESSOR_FAMILY
#define ARM_PROCESSOR_FAMILY(ENUM)
#endif

ARM_PROCESSOR_FAMILY(CortexA15)
ARM_PROCESSOR_FAMILY(CortexA78C)
ARM_PROCESSOR_FAMILY(CortexA12)
ARM_PROCESSOR_FAMILY(Krait)
ARM_PROCESSOR_FAMILY(Exynos)
ARM_PROCESSOR_FAMILY(CortexA8)
ARM_PROCESSOR_FAMILY(CortexA57)
ARM_PROCESSOR_FAMILY(CortexA55)
ARM_PROCESSOR_FAMILY(CortexA78AE)
ARM_PROCESSOR_FAMILY(CortexA75)
ARM_PROCESSOR_FAMILY(CortexM7)
ARM_PROCESSOR_FAMILY(CortexA7)
ARM_PROCESSOR_FAMILY(Swift)
ARM_PROCESSOR_FAMILY(CortexM3)
ARM_PROCESSOR_FAMILY(CortexA72)
ARM_PROCESSOR_FAMILY(CortexA76)
ARM_PROCESSOR_FAMILY(CortexA9)
ARM_PROCESSOR_FAMILY(Kryo)
ARM_PROCESSOR_FAMILY(CortexA17)
ARM_PROCESSOR_FAMILY(CortexR52)
ARM_PROCESSOR_FAMILY(CortexA73)
ARM_PROCESSOR_FAMILY(CortexX1C)
ARM_PROCESSOR_FAMILY(CortexX1)
ARM_PROCESSOR_FAMILY(CortexA77)
ARM_PROCESSOR_FAMILY(CortexA53)
ARM_PROCESSOR_FAMILY(CortexR4)
ARM_PROCESSOR_FAMILY(CortexA78)
ARM_PROCESSOR_FAMILY(CortexA35)
ARM_PROCESSOR_FAMILY(CortexR7)
ARM_PROCESSOR_FAMILY(NeoverseV1)
ARM_PROCESSOR_FAMILY(CortexA5)
ARM_PROCESSOR_FAMILY(CortexA710)
ARM_PROCESSOR_FAMILY(CortexA32)
ARM_PROCESSOR_FAMILY(CortexR52plus)
ARM_PROCESSOR_FAMILY(CortexR5)

#undef ARM_PROCESSOR_FAMILY

#ifndef ARM_ARCHITECTURE
#define ARM_ARCHITECTURE(ENUM)
#endif

ARM_ARCHITECTURE(ARMv6t2)
ARM_ARCHITECTURE(ARMv7m)
ARM_ARCHITECTURE(ARMv6k)
ARM_ARCHITECTURE(ARMv6)
ARM_ARCHITECTURE(ARMv85a)
ARM_ARCHITECTURE(ARMv83a)
ARM_ARCHITECTURE(ARMv84a)
ARM_ARCHITECTURE(ARMv7ve)
ARM_ARCHITECTURE(ARMv9a)
ARM_ARCHITECTURE(ARMv87a)
ARM_ARCHITECTURE(ARMv8r)
ARM_ARCHITECTURE(ARMv6m)
ARM_ARCHITECTURE(ARMv93a)
ARM_ARCHITECTURE(ARMv5t)
ARM_ARCHITECTURE(ARMv6kz)
ARM_ARCHITECTURE(ARMv7r)
ARM_ARCHITECTURE(ARMv81mMainline)
ARM_ARCHITECTURE(ARMv94a)
ARM_ARCHITECTURE(ARMv4t)
ARM_ARCHITECTURE(ARMv4)
ARM_ARCHITECTURE(ARMv81a)
ARM_ARCHITECTURE(ARMv5te)
ARM_ARCHITECTURE(ARMv82a)
ARM_ARCHITECTURE(ARMv7em)
ARM_ARCHITECTURE(ARMv88a)
ARM_ARCHITECTURE(ARMv8mMainline)
ARM_ARCHITECTURE(ARMv92a)
ARM_ARCHITECTURE(ARMv7a)
ARM_ARCHITECTURE(ARMv8mBaseline)
ARM_ARCHITECTURE(ARMv5tej)
ARM_ARCHITECTURE(ARMv95a)
ARM_ARCHITECTURE(ARMv91a)
ARM_ARCHITECTURE(ARMv8a)
ARM_ARCHITECTURE(ARMv86a)
ARM_ARCHITECTURE(ARMv89a)
ARM_ARCHITECTURE(ARMv6sm)

#undef ARM_ARCHITECTURE

